#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: admin.py 9948 2017-05-07 06:08:11Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2017-05-07 14:08:11 +0800 (Sun, 07 May 2017) $
# $Revision: 9948 $

from django.contrib import admin

from Zephyrus.landing.models import Email

class EmailAdmin(admin.ModelAdmin):
    list_display = (
        'email', 'fromUrl', 'date',
    )

admin.site.register(Email, EmailAdmin)
